const { consoleError, consoleBlue } = require('./console');
const { build } = require('vite');
const { viteConfig } = require('./build/vite.config');
const { getExtensionInfo, getDistPath } = require('./util');
const path = require('path');
const fs = require('fs');

async function viteBuild(command) {
  try {
    require('./version');
    const { id, path: extensionPath } = getExtensionInfo(command.id);
    const pageEntry = {
      [id]: path.join(extensionPath, 'src', 'index.js')
    };
    if (!fs.existsSync(getDistPath())) {
      fs.mkdirSync(getDistPath());
    }
    fs.readdirSync(getDistPath()).forEach((fname) => {
      if (fname.includes(id)) {
        fs.rmSync(path.join(getDistPath(), fname));
      }
    });
    await build(viteConfig(pageEntry));
  } catch (err) {
    consoleError('build error: ', err);
    throw 'build_error';
  }
}

async function cliBuild(command) {
  try {
    await viteBuild(command);
  } catch (err) {}
}

module.exports = {
  cliBuild,
  viteBuild
};
