module.exports = {
  cwd: process.cwd(),
  openAipVersion: '/openapi',
  defaultExtensionDir: 'extensions',
  configFile: 'extension.json',
  buildDir: 'dist',
  package: 'package.json',
  questions: commands => {
    const { store, token, theme } = commands;
    return require('inquirer').prompt([
      {
        name: 'store',
        type: 'input',
        default: store,
        message: 'Please enter your store（Eg: https://developer.myshoplaza.com）',
        when: () => {
          if (!store) return true;
          try {
            new URL(store);
          } catch (e) {
            return 'Incorrect store'
          }
          return false;
        },
        validate: text => {
          if (!text) return false;
          try {
            new URL(text);
          } catch (e) {
            return 'Incorrect store'
          }
          return true;
        }
      },
      {
        name: 'token',
        type: 'input',
        default: token,
        when: !token,
        message: 'Please enter your token（Private app token）',
        validate: text => !!text
      }
    ]);
  },
  pullQuestion: () => {
    return require('inquirer').prompt([
      {
        type: 'list',
        name: 'pullType',
        message: 'Choose pull type: ',
        default: 'extension',
        prefix: '*',
        choices: [
          {
            name: 'Extension',
            value: 'extension'
          },
          {
            name: 'Fields',
            value: 'fields',
          },
          // TODO:
          // {
          //   name: 'Source',
          //   value: 'source'
          // }
        ]
      }
    ]);
  },
  outputDirPathQuestion: (commands = {}) => {
    const outputDirPath = process.env.OUTPUT_DIR_PATH || commands.outputDirPath;
    return require('inquirer').prompt([
      {
        type: 'input',
        name: 'outputDirPath',
        message: 'Please enter extension output directory relative path(Eg: ./src/xxx ): ',
        default: outputDirPath || './dist/chick-extension',
        when: !outputDirPath,
        validate: text => !!text
      }
    ]);
  },
  dirPathQuestion: (commands = {}) => {
    const dirPath = process.env.DIR_PATH || commands.dirPath;
    return require('inquirer').prompt([
      {
        type: 'input',
        name: 'dirPath',
        message: 'Please enter extension directory relative path(Eg: ./src/xxx ): ',
        default: dirPath || './extensions',
        when: !dirPath,
        validate: text => !!text
      }
    ]);
  }
};