const api = require('./api');
const { verifyConfig } = require('./verify');
const { useSelectExtensionMode } = require('./util');
const inquirer = require('inquirer');
const { consoleSuccess, consoleError, consoleBlue } = require('./console');

module.exports = async () => {
  try {
    await verifyConfig();
    const extensionInfo = await initSelectedExtensionInfo();
    await deployExtension(extensionInfo);
  } catch (error) {
    error.response ? consoleError(`Error: ${error.response.status}-${error.response.config.url}`) : consoleError(error);
  }
};

async function initSelectedExtensionInfo() {
  const res = await api.getExtensionList();
  const extensionList = res.data?.data?.extensions || [];
  return useSelectExtensionMode(extensionList, 'deploy');
}

async function deployExtension(extensionInfo) {
  const res = await api.getVersionList({
    extension_id: extensionInfo.extension_id
  });
  const versionList = res.data?.data?.extensions || [];
  const choices = versionList.map((item) => ({
    name: `v${item.version}${item.publish_status === 'published' ? '(Published)' : ''}`,
    value: item.id
  }));
  const { versionId, confirm } = await inquirer.prompt([
    {
      type: 'list',
      name: 'versionId',
      message: `Please select a version`,
      prefix: '*',
      loop: false,
      choices
    },
    {
      type: 'confirm',
      name: 'confirm',
      message: 'Are you sure you want to deploy?',
      default: false
    }
  ]);

  if (confirm) {
    const versionInfo = versionList.find((item) => item.id === versionId);
    await api.deployExtension({
      extension_id: versionInfo.extension_id,
      id: versionInfo.id
    });
    consoleSuccess(`Successfully deployed the extension '${versionInfo.name}(v${versionInfo.version})'.`);
  } else {
    consoleBlue('Deploy cancelled');
  }
}
