const inquirer = require('inquirer');
const api = require('./api');
const { verifyConfig } = require('./verify');
const { useSelectExtensionMode, getProjectConfig } = require('./util');
const { consoleSuccess, consoleError } = require('./console');

module.exports = async () => {
  try {
    await verifyConfig();
    const extensionInfo = await initSelectedExtensionInfo();
    await previewExtension(extensionInfo);
  } catch (error) {
    error.response ? consoleError(`Error: ${error.response.status}-${error.response.config.url}`) : consoleError(error);
  }
};

async function initSelectedExtensionInfo() {
  const res = await api.getExtensionList();
  const extensionList = res.data?.data?.extensions || [];
  return useSelectExtensionMode(extensionList, 'preview');
}

async function previewExtension(extensionInfo) {
  const resp = await api.getVersionList({
    extension_id: extensionInfo.extension_id
  });
  const versionList = resp.data?.data?.extensions || [];
  const choices = versionList.map((item) => ({
    name: `v${item.version}${item.publish_status === 'published' ? '(Published)' : ''}`,
    value: item.id
  }));
  const { versionId } = await inquirer.prompt([
    {
      type: 'list',
      name: 'versionId',
      message: `Please select a version`,
      prefix: '*',
      loop: false,
      choices
    }
  ]);
  const versionInfo = versionList.find((item) => item.id === versionId);
  const res = await api.previewExtension({
    extension_id: versionInfo.extension_id,
    id: versionInfo.id
  });
  const checkoutUrl = res.data?.data?.checkout_url;
  const { store: baseUrl } = getProjectConfig();
  const url = new URL(checkoutUrl, baseUrl);
  url.searchParams.append('step', 'contact_information');
  consoleSuccess(`Your extension's preview URL: ${url.toString()}`);
}
