const api = require('./api');
const { verifyConfig } = require('./verify');
const { useSelectExtensionMode } = require('./util');
const inquirer = require('inquirer');
const { consoleSuccess, consoleBlue, consoleError } = require('./console');

module.exports = async () => {
  try {
    await verifyConfig();
    const extensionInfo = await initSelectedExtensionInfo();
    await undeployExtension(extensionInfo);
  } catch (error) {
    error.response ? consoleError(`Error: ${error.response.status}-${error.response.config.url}`) : consoleError(error);
  }
};

async function initSelectedExtensionInfo() {
  const res = await api.getExtensionList({
    status: 'published'
  });
  const extensionList = res.data?.data?.extensions || [];
  return useSelectExtensionMode(extensionList, 'undeploy');
}

async function undeployExtension(extensionInfo) {
  const { confirm } = await inquirer.prompt([
    {
      type: 'confirm',
      name: 'confirm',
      message: 'Are you sure you want to undeploy?',
      default: false
    }
  ]);
  if (confirm) {
    await api.undeployExtension({ extension_id: extensionInfo.extension_id });
    consoleSuccess(`Successfully undeployed the extension '${extensionInfo.name}'.`);
  } else {
    consoleBlue('Undeploy cancelled');
  }
}
