const path = require('path');
const fs = require('fs-extra');
const AdmZip = require('adm-zip');
const chalk = require('chalk');

const {
  SSO_AUTH_URL,
  ACCOUNT_URL,
  CLIENT_ID,
  DEV_SSO_AUTH_URL,
  DEV_ACCOUNT_URL,
  DEV_CLIENT_ID,
  STG_CLIENT_ID,
  STG_ACCOUNT_URL,
  STG_SSO_AUTH_URL
} = require('./config');

const ZIP_IGNORE_FOLDER = ['.git', '.DS_Store'];

exports.unzipTheme = (zipPath, outputPath) => {
  const zip = new AdmZip(zipPath);
  const zipEntries = zip.getEntries();
  const innerName = zipEntries[0].entryName.split('/')[0];
  zipEntries.forEach((entry) => {
    zip.extractEntryTo(
      entry,
      path.join(outputPath, entry.entryName.replace(`${innerName}`, '').replace(path.basename(entry.entryName), '')),
      false,
      true
    );
  });
  fs.removeSync(zipPath);
};

exports.zipTheme = (filePath, themeName) => {
  const zip = new AdmZip();

  // Old code
  // zip.addLocalFolder(filePath, themeName);

  // zip, but ignore some folder
  const lsDir = fs.readdirSync(filePath);
  lsDir.forEach((lsItem) => {
    const lsItemStat = fs.statSync(path.join(filePath, lsItem));

    if (ZIP_IGNORE_FOLDER.includes(lsItem)) {
      return;
    }

    if (lsItemStat.isDirectory()) {
      zip.addLocalFolder(path.join(filePath, lsItem), path.join(themeName, lsItem));
    } else if (lsItemStat.isFile()) {
      zip.addLocalFile(path.join(filePath, lsItem), path.join(themeName, lsItem));
    }
  });

  zip.writeZip(`${process.cwd()}/${themeName}.zip`);
};

exports.getThemeFilenameTypeAndLocation = (filename) => {
  const result = filename.split(path.sep);
  const location = result.pop();
  const type = result.pop();
  return {
    type,
    location
  };
};

exports.formatThemeList = (themes, defaultThemeId) => {
  return themes.map((theme) => ({
    ...theme,
    name: `${theme.name} (${theme.id ? chalk.green(theme.id) : ''}) ${
      theme.id === defaultThemeId ? chalk.green('[live]') : chalk.yellow('[unpublished]')
    }`,
    value: theme.id
  }));
};

exports.sleep = (time) => new Promise((resolve) => setTimeout(resolve, time));

function getEnv(store) {
  return store.includes('dev.myshoplaza.com') ? 'dev' : store.includes('stg.myshoplaza.com') ? 'stg' : 'prod';
}

const CLIENT_ID_ENV_MAP = {
  dev: DEV_CLIENT_ID,
  stg: STG_CLIENT_ID,
  prod: CLIENT_ID
};

exports.getClientId = (store) => {
  return CLIENT_ID_ENV_MAP[getEnv(store)];
};

const ACCOUNT_URL_ENV_MAP = {
  dev: DEV_ACCOUNT_URL,
  stg: STG_ACCOUNT_URL,
  prod: ACCOUNT_URL
};
exports.getAccountUrl = (store) => {
  return ACCOUNT_URL_ENV_MAP[getEnv(store)];
};

const SSO_AUTH_URL_MAP = {
  dev: DEV_SSO_AUTH_URL,
  stg: STG_SSO_AUTH_URL,
  prod: SSO_AUTH_URL
};

exports.getSSOAuthUrl = (store) => {
  return SSO_AUTH_URL_MAP[getEnv(store)];
};
